@@ -1,4 +1,5 @@
 from logging import getLogger
+from pathlib import Path
 from shutil import rmtree
 
 from deckz.cli import app
@@ -6,10 +7,10 @@ from deckz.paths import Paths
 
 
 @app.command()
-def clean(deck_path: str = ".") -> None:
+def clean(deck_path: Path = Path(".")) -> None:
     """Wipe the build directory."""
     logger = getLogger(__name__)
-    paths = Paths(deck_path)
+    paths = Paths.from_defaults(deck_path)
     if not paths.build_dir.exists():
         logger.info(f"Nothing to do: {paths.build_dir} doesn't exist")
     else:
